@@ -3,6 +3,7 @@ var path = require('path');
 var url = require('url');
 var crypto = require('crypto');
 var EventEmitter = require('events').EventEmitter;
+var mime = require('mime');
 
 // Third party modules
 var _ = require('underscore'),
@@ -10,8 +11,7 @@ var _ = require('underscore'),
     get = require('get'),
     zipfile = require('zipfile'),
     Step = require('step'),
-    utils = require('./util.js'),
-    sqlite3 = require('sqlite3');
+    utils = require('./util.js');
 
 // Known SRS values
 var SRS = {
@@ -89,16 +89,21 @@ function metapath(filepath) {
     return path.join(path.dirname(filepath), '.' + path.basename(filepath));
 }
 
-// Taken from node-get
 function guessExtension(headers) {
     if (headers['content-disposition']) {
-        var match = headers['content-disposition'].match(/filename=\"([^"]+)\"/);
+        // Taken from node-get
+        var match = headers['content-disposition'].match(/filename=['"]?([^'";]+)['"]?/);
         if (match) {
             var ext = path.extname(match[1]);
             if (ext) {
                 return ext;
             }
         }
+    } else if (headers['content-type']) {
+        var ext = mime.extension(headers['content-type'].split(';')[0]);
+        if (ext) {
+            return '.' + ext;
+        }
     }
     return false;
 };
@@ -336,10 +341,12 @@ function resolve(options, callback) {
         var group = this.group();
         resolved.Layer.forEach(function(l, index) {
             var d = l.Datasource;
-            if (d.type == 'sqlite' && d.table) {
+            // mapnik's sqlite plugin resolves attached databases
+            // relative to the main database, but in tilemill we prefer
+            // to interpret relative to the project so we resolve here
+            if (d.type == 'sqlite' && d.table && d.attachdb) {
                 var next = group();
-                if (!d.attachdb) d.attachdb = '';
-                var db = new sqlite3.Database(d.file), dbs = d.attachdb.split(',');
+                var dbs = d.attachdb.split(',');
                 Step(function() {
                     var group = this.group();
                     for (i = 0; i < dbs.length; i++) (function(next) {
@@ -352,60 +359,13 @@ function resolve(options, callback) {
                             file = path.resolve(path.join(base, file));
                             dbs[i] = dbs[i].split('@').shift() + '@' + file;
                         }
-
-                        db.run("ATTACH DATABASE '" +
-                            file + "' AS " +
-                            dbs[i].split('@').shift(),
-                            function(err) {
-                            next(err);
-                        });
+                        next();
+                        
                     })(group());
                 }, function(err) {
                     if (err) throw err;
                     d.attachdb = dbs.join(',');
-                    var self = this;
-                    // Attach databases.
-                    // If this query returns results, it's a Spatialite database.
-                    // Otherwise it's normal SQLite.
-                    db.all("SELECT name FROM sqlite_master WHERE type='table' AND name='geometry_columns_auth'",
-                        function(err, result) {
-                        if (err) throw err;
-
-                        if (result.length) {
-                            d.wkb_format = 'spatialite';
-                        }
-                        self();
-                    });
-                }, function(err) {
-                    if (err) throw err;
-                    var group = this.group(),
-                        parts = d.table.replace(/^\(|\)$/g, '')
-                        .split(/WHERE/i).shift()
-                        .split(/LIMIT/i).shift()
-                        .split(/FROM/i).pop()
-                        .split(/(LEFT|INNER|RIGHT)\s+JOIN/i);
-                    _(parts).each(function(part, key) {
-                        if (key % 2 === 0) (function(next) {
-                            var table = part.split(/ON/i)
-                                .shift()
-                                .split('.')
-                                .pop()
-                                .replace(/^\s*|\s*$/g, '');
-                            // Query geometry table looking for pk to use as `key_field`.
-                            db.all('PRAGMA table_info(' + table + ')', function(err, result) {
-                                if (err) return next(err);
-                                _(result).each(function(row) {
-                                    if (row.pk) {
-                                        d.key_field = row.name;
-                                    }
-                                });
-                                next();
-                            });
-                        })(group());
-                    });
-                }, function(err) {
-                    db.close();
-                    next(err);
+                    return next(err);
                 });
             }
         });
@@ -454,6 +414,7 @@ function resolve(options, callback) {
                 case '.csv':
                 case '.tsv': // google refine uses tsv for tab-delimited
                 case '.txt': // resonable assumption that .txt is csv?
+                    d.quiet = d.quiet || true; // Supress verbose mapnik error reporting by default.
                     d.type = d.type || 'csv';
                     l.srs = l.srs || SRS.WGS84;
                     break;
